@@ -41,10 +41,13 @@ def ml_pipe(file_location, target_var, test_size):
     ############## Below line scale the numerical features #######################
     df[col_not_contain_tar] = std_scaler.fit_transform(df[col_not_contain_tar])
     ################# Below line encode the categorical variables ######################
-    df1 = pd.get_dummies(df[col_cat_type])
-    df.drop(columns = col_cat_type, inplace = True)
-    df = pd.concat([df, df1], axis=1).reindex(df.index)
-    X = df
+    if len(col_cat_type) > 0:
+        df1 = pd.get_dummies(df[col_cat_type])
+        df.drop(columns = col_cat_type, inplace = True)
+        df = pd.concat([df, df1], axis=1).reindex(df.index)
+        X = df
+    else:
+        X = df
     x_train, x_test, y_train, y_test = train_test_split(X,y, test_size=test_size)
     return x_train, x_test, y_train, y_test
 
